@@ -4,9 +4,17 @@ from microbase.exceptions import RouteError
 from microbase.views import BaseView
 
 
+DEFAULT_GROUP = 'default'
+
+
 class Route(object):
-    def __init__(self, handler: BaseView, uri: str, methods: Iterable = frozenset({'GET'}),
-                 strict_slashes: bool = False, name: str = None):
+    def __init__(self,
+                 handler: BaseView,
+                 uri: str, methods: Iterable = frozenset({'GET'}),
+                 strict_slashes: bool = False,
+                 name: str = None,
+                 *,
+                 group: str = DEFAULT_GROUP):
         super(Route, self).__init__()
 
         if not isinstance(handler, BaseView):
@@ -16,6 +24,7 @@ class Route(object):
         self._uri = uri
         self._methods = methods
         self._strict_slashes = strict_slashes
+        self._group = group
 
         self._name = name
         if self._name is None:
@@ -40,3 +49,7 @@ class Route(object):
     @property
     def name(self):
         return self._name
+
+    @property
+    def group(self):
+        return self._group
